; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;-| Hold Button |----------------------------------------------------------
; Please define Anim 74140108 in your AIR file if AND ONLY IF you place these
; 7 Hold Button commands immediately after the 11 Single Button and Hold Dir
; commands at the very top of your CMD list, as demonstrated here.
; In this version of the AI code, these commands are only used by the XOR
; method, and thus are optional.  But there remains a possibility that a
; future version of the helper method might be helped by having these
; commands placed here, and Anim 74140108 would then be used to indicate
; that a partner character has a compatible CMD.

[Command]
name = "holda"
command = /a
time = 1

[Command]
name = "holdb"
command = /b
time = 1

[Command]
name = "holdc"
command = /c
time = 1

[Command]
name = "holdx"
command = /x
time = 1

[Command]
name = "holdy"
command = /y
time = 1

[Command]
name = "holdz"
command = /z
time = 1

[Command]
name = "holdstart"
command = /s
time = 1

;--- None of your own command definitions should be above this line. ---

;-| CPU |--------------------------------------------------------------
; Note that if you make any changes to the basic one-button or recovery
; commands, you'll need to make the same changes to their matching commands here
; and/or in the XOR VarSet controller.  That includes things like, for example:
;  * changing the recovery command to use a different combination of buttons.
;  * renaming the b button command as "d", or the start button command as "s".
;  * switching the button names around, e.g. so button y triggers "a" and button a triggers "y".
;  * having more than one way to trigger the same command name.
; If you understand how the XOR method works, the proper changes should be obvious.
; If you don't understand it, then simply disable the lines in the XOR VarSet
; controller that correspond to the commands you've altered.

[Command]
name = "a2"
command = a
time = 1

[Command]
name = "b2"
command = b
time = 1

[Command]
name = "c2"
command = c
time = 1

[Command]
name = "x2"
command = x
time = 1

[Command]
name = "y2"
command = y
time = 1

[Command]
name = "z2"
command = z
time = 1

[Command]
name = "start2"
command = s
time = 1

[Command]
name = "holdfwd2"
command = /$F
time = 1

[Command]
name = "holdback2"
command = /$B
time = 1

[Command]
name = "holdup2"
command = /$U
time = 1

[Command]
name = "holddown2"
command = /$D
time = 1

[Command]
name = "holda2"
command = /a
time = 1

[Command]
name = "holdb2"
command = /b
time = 1

[Command]
name = "holdc2"
command = /c
time = 1

[Command]
name = "holdx2"
command = /x
time = 1

[Command]
name = "holdy2"
command = /y
time = 1

[Command]
name = "holdz2"
command = /z
time = 1

[Command]
name = "holdstart2"
command = /s
time = 1

[Command]
name = "recovery2"
command = x+y
time = 1

;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
name = "TripleKFPalm"
command = ~D, DF, F, D, DF, F, x
time = 20

;-| Special Motions |------------------------------------------------------
[Command]
name = "punch"
command = /x
time = 1

[Command]
name = "punch"
command = /y
time = 1

[Command]
name = "kick"
command = /a
time = 1

[Command]
name = "kick"
command = /b
time = 1

[Command]
name = "specops"
command = /c
time = 1

[Command]
name = "specops"
command = /z
time = 1

[Command]
name = "tap"
command = y
time = 1

[Command]
name = "tap"
command = z
time = 1

[Command]
name = "tak"
command = b
time = 1

[Command]
name = "tak"
command = c
time = 1

[Command]
name = "princesparq"
command = /F,x+a
time = 1

[Command]
name = "princesparq"
command = /F,y+b
time = 1

[Command]
name = "princesparq"
command = /F,z+c
time = 1


;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

[Command]
name = "SupahJump"
;command = ~$D, $U
command = ~$D, $U
time = 5
buffer.time = 2

[Command]
name = "ChargedSupahJump"
;command = ~$D, $U
command = ~12$D, $U
time = 5
buffer.time = 2

[Command]
name = "upper_what"
command = ~15$D, $U, x
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, y
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, z
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, a
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, b
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, c
time = 10


;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

; The main purpose of having these next two controllers here at the top of
; StateDef -1 is to make sure the AI helper never changes to a different state,
; nor encounters any VarSets within State -1.
; But they also improve efficiency by preventing Mugen from wasting time
; processing the entire State -1 for the helper.
[State -1, AI Helper Check]
type = ChangeState
trigger1 = IsHelper(9741)
value = 9741

[State -1, AI Helper Check 2]
type = ChangeState
trigger1 = IsHelper(9742)
value = 9742

[State -1, Considerator Reset]
type = VarSet
trigger1 = 1
var(52) = 0

;===========================================================================
;This is not a move, but it sets up var(1) to be 1 if conditions are right
;for a combo into a special move (used below).
;Since a lot of special moves rely on the same conditions, this reduces
;redundant logic.
[State -1, Combo condition Reset]
type = VarSet
trigger1 = 1
var(9) = 0

[State -1, Combo condition Check]
type = VarSet
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact
var(9) = 1


; AI-related stuff starts here

[State AI, Consider backing off]
type = VarSet
triggerall = var(55)
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = random < 200 + (123*(prevstateno = 440 && (p2stateno=[5070,5100]) ) )
triggerall = numenemy
triggerall = (p2stateno = [5110,5130]) || ((enemynear,time <= 10) && (enemynear,prevstateno = 5120))
triggerall = p2bodydist x <= 40
trigger1 = stateno != [20,105]
trigger1 = ctrl
var(52) = 105

[State AI, Consider S.X]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (8*(var(55)*var(55)))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150)
triggerall = p2stateno != [5080,5130]
triggerall = p2statetype != L
triggerall = p2bodydist x = [-5,23*const(size.xscale)]
triggerall = p2dist y >= -60*const(size.yscale) - (enemynear,vel y*4)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -60*const(size.yscale)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = prevstateno != 200
triggerall = prevstateno != 205 || p2bodydist x > 18 || (enemynear,backedgebodydist > 15) || moveguarded
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger2 = power >= 100 || (prevstateno = [200,649])
trigger2 = movehit
trigger2 = stateno != 200
trigger2 = (enemynear,GetHitVar(hittime) >= 4  ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger2 = p2statetype != A
var(52) = 200
ignorehitpause = 1

[State AI, Consider F.X]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (6*(var(55)*var(55)))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 50)
triggerall = p2stateno != [5080,5130]
triggerall = p2statetype != L
triggerall = p2bodydist x = [-5,49*const(size.xscale)]
triggerall = p2dist y >= -60*const(size.yscale) - (enemynear,vel y*10)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -60*const(size.yscale)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = prevstateno != 210
triggerall = prevstateno != 205 || p2bodydist x > 18 || (enemynear,backedgebodydist > 15) || moveguarded
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger2 = power >= 100 || (prevstateno = [200,649])
trigger2 = movehit
trigger2 = stateno != 210
trigger2 = (enemynear,GetHitVar(hittime) >= 10  ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger2 = p2statetype != A
var(52) = 210
ignorehitpause = 1

[State AI, Consider D.X]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (4*(var(55)*var(55)))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 100)
triggerall = p2stateno != [5080,5130]
triggerall = p2statetype != L
triggerall = p2bodydist x = [-5,18*const(size.xscale)]
triggerall = p2dist y >= -60*const(size.yscale) - (enemynear,vel y*4)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -50*const(size.yscale)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = prevstateno != 400
triggerall = prevstateno != 205 || p2bodydist x > 18 || (enemynear,backedgebodydist > 15) || moveguarded
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger2 = power >= 100 || (prevstateno = [200,649])
trigger2 = movehit
trigger2 = stateno != 400
trigger2 = (enemynear,GetHitVar(hittime) >= 4  ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger2 = p2statetype != A
var(52) = 400
ignorehitpause = 1

[State AI, Consider S.A]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (6*(var(55)*var(55)))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 90)
triggerall = p2stateno != [5080,5130]
triggerall = p2statetype != L
triggerall = p2bodydist x = [-5,28*const(size.xscale)]
triggerall = p2dist y >= -60*const(size.yscale) - (enemynear,vel y*6)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -40*const(size.yscale)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = prevstateno != 230
triggerall = prevstateno != 205 || p2bodydist x > 18 || (enemynear,backedgebodydist > 15) || moveguarded
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger2 = power >= 100 || (prevstateno = [200,649])
trigger2 = movehit
trigger2 = stateno != 230
trigger2 = (enemynear,GetHitVar(hittime) >= 6  ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger2 = p2statetype != A
var(52) = 230
ignorehitpause = 1

[State AI, Consider F.A]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (6*(var(55)*var(55)))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 40)
triggerall = p2stateno != [5080,5130]
triggerall = p2statetype != L
triggerall = p2bodydist x = [-5,61*const(size.xscale)]
triggerall = p2dist y >= -70*const(size.yscale) - (enemynear,vel y*10)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -60*const(size.yscale)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = prevstateno != 640
triggerall = prevstateno != 205 || p2bodydist x > 18 || (enemynear,backedgebodydist > 15) || moveguarded
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger2 = power >= 100 || (prevstateno = [200,649])
trigger2 = movehit
trigger2 = stateno != 640
trigger2 = (enemynear,GetHitVar(hittime) >= 10  ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger2 = p2statetype != A
var(52) = 640
ignorehitpause = 1

[State AI, Consider B.A]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (4*(var(55)*var(55)))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 30)
triggerall = p2stateno != [5080,5130]
triggerall = p2statetype != L
triggerall = p2bodydist x = [-5,47*const(size.xscale)]
triggerall = p2dist y >= -60*const(size.yscale) - (enemynear,vel y*16)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -40*const(size.yscale)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = prevstateno != 240
triggerall = prevstateno != 205 || p2bodydist x > 18 || (enemynear,backedgebodydist > 15) || moveguarded
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger2 = power >= 100 || (prevstateno = [200,649])
trigger2 = movehit
trigger2 = stateno != 240
trigger2 = (enemynear,GetHitVar(hittime) >= 16  ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger2 = p2statetype != A
var(52) = 240
ignorehitpause = 1

[State AI, Consider D.A]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (7*(var(55)*var(55)))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 100)
triggerall = p2stateno != [5080,5130]
triggerall = p2statetype != L
triggerall = p2bodydist x = [-5,25*const(size.xscale)]
triggerall = p2dist y >= -10*const(size.yscale) - (enemynear,vel y*4)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = prevstateno != 430
triggerall = prevstateno != 205 || p2bodydist x > 18 || (enemynear,backedgebodydist > 15) || moveguarded
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger2 = power >= 100 || (prevstateno = [200,649])
trigger2 = movehit
trigger2 = stateno != 430
trigger2 = (enemynear,GetHitVar(hittime) >= 4  ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger2 = p2statetype != A
var(52) = 430
ignorehitpause = 1

[State AI, Consider OV.K]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (4*(var(55)*var(55)))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 40)
triggerall = p2stateno != [5080,5130]
triggerall = p2statetype != L
triggerall = p2bodydist x = [ifelse(p2statetype=C,-5,15),50*const(size.xscale)]
triggerall = p2dist y >= -50*const(size.yscale) - (enemynear,vel y*18)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -10*const(size.yscale)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = prevstateno != 640
triggerall = prevstateno != 205 || p2bodydist x > 18 || (enemynear,backedgebodydist > 15) || moveguarded
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger2 = movehit
trigger2 = (enemynear,GetHitVar(hittime) >= 18  ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger2 = p2statetype != A
var(52) = 1150
ignorehitpause = 1

[State AI, Consider B.X]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (14*(var(55)*var(55))) * ifelse((stateno = 205 && movehit),2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 550)
triggerall = p2stateno != [5080,5130]
triggerall = p2statetype != L
triggerall = p2bodydist x = [-5,17*const(size.xscale)]
triggerall = p2dist y >= -60*const(size.yscale) - (enemynear,vel y*4)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -40*const(size.yscale)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger2 = power >= 100 || (prevstateno = [200,649])
trigger2 = movehit
trigger2 = stateno != 205
trigger2 = (enemynear,GetHitVar(hittime) >= 4  ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger2 = p2statetype != A
var(52) = 205
ignorehitpause = 1

[State AI, J.X]
type = Varset
triggerall = numenemy
triggerall = var(52) = 0 || random < 123
triggerall = var(55)
triggerall = p2bodydist x = [-38+(vel x*4)+(enemynear,vel x*4),60+(vel x*4)+(enemynear,vel x*4)]
triggerall = P2dist y = [-57+(vel y*4)+(enemynear,vel y*4),ifelse(p2movetype=A&&vel y>=0,80,60)+(vel y*4)+(enemynear,vel y*4)]
triggerall = Statetype = A
triggerall = p2stateno != [5100,5120]
triggerall = p2Statetype = A || p2movetype = A || vel y >= 0
triggerall = (stateno != [120,169])
triggerall = random < (10*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = time >= 7-var(55) || random < 10
trigger1 = ctrl
var(52) = 630

[State AI, Consider Kicking the fuck out]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (5*(var(55)*var(55)))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 550)
triggerall = p2stateno != [5080,5130]
triggerall = p2statetype != L
triggerall = p2bodydist x = [20*const(size.xscale),100*const(size.xscale)]
triggerall = p2dist y >= -60*const(size.yscale) - (enemynear,vel y*4)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -40*const(size.yscale)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger2 = (prevstateno != [200,649])
trigger2 = movehit
trigger2 = (enemynear,GetHitVar(hittime) >= 2  ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger2 = p2statetype != A
var(52) = 1050
ignorehitpause = 1

[State AI, Consider Kicking the sky]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (5*(var(55)*var(55)))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 550)
triggerall = p2stateno != [5080,5130]
triggerall = p2statetype != L
triggerall = p2bodydist x = [ifelse(p2statetype=A,-5,5*const(size.xscale)),45*const(size.xscale)]
triggerall = p2dist y >= -80*const(size.yscale) - (enemynear,vel y*6)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -25*const(size.yscale)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger2 = (prevstateno != [200,649])
trigger2 = movehit
trigger2 = (enemynear,GetHitVar(hittime) >= 6  ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger2 = p2statetype != A
var(52) = 1100
ignorehitpause = 1

[State AI, Consider shooting dudes]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (2*(var(55)*var(55))) + ceil(p2bodydist x / 2)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 40)
triggerall = p2stateno != [5080,5130]
triggerall = p2statetype != L
;triggerall = power >= 100
triggerall = p2bodydist x >= 80*const(size.xscale)
triggerall = statetype != A
triggerall = p2statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger2 = (prevstateno != [200,649])
trigger2 = movehit
trigger2 = (enemynear,GetHitVar(hittime) >= 6  ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger2 = p2statetype != A
var(52) = 1200
ignorehitpause = 1

[State AI, Consider Advancing]
type = VarSet
triggerall = var(55)
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = random < ((7*(var(55)*var(55))) + life-p2life  )
triggerall = ((enemynear, ctrl = 0) && p2movetype != A) || (p2movetype = A && (enemynear, facing = facing)) || (random<100) || (time>=60) || (prevstateno=100)
triggerall = (p2stateno != [5080,5130])
triggerall = p2bodydist x >= 10*const(size.xscale)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != [20,105]
trigger1 = stateno != [10,12]
trigger1 = ctrl
var(52) = 100

[State AI, Guard S]
type = ChangeState
triggerall = stateno != 40
triggerall = random < 125*var(55)
triggerall = (var(55)) && (StateType != A) && (Ctrl) && (EnemyNear, Facing != Facing) && (var(50)<40)
trigger1 = (P2StateType != C) && (((P2MoveType = A) && (inguarddist)) || (EnemyNear, NumProj > 0))
value = 130

[State AI, Guard L]
type = ChangeState
triggerall = stateno != 40
triggerall = random < 125*var(55)
triggerall = (var(55)) && (StateType != A) && (Ctrl) && (EnemyNear, Facing != Facing) && (var(50)<40)
trigger1 = (P2StateType = C) && (((P2MoveType = A) && (inguarddist)) || (EnemyNear, NumProj > 0))
value = 131


; AI-related stuff ends here

;===========================================================================
;---------------------------------------------------------------------------
[State -1, Stand Punch]
type = ChangeState
value = 1050
triggerall = (var(55)<5 && (((command = "punch" && command = "kick") || (command = "specops")) && command = "holdfwd")) || var(52) = 1050
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = ((stateno = 200 || stateno = 400 || stateno = 430) && animelemtime(4)>=0) || ((stateno = 230 || stateno = 210 || stateno = 205) && animelemtime(5)>=0) || ((stateno = 240 || stateno = 640) && animelemtime(9)>=0)

[State -1, Stand Punch]
type = ChangeState
value = 1200
triggerall = (var(55)<5 && (((command = "punch" && command = "kick") || (command = "specops")) && command = "holdback")) || var(52) = 1200
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = ((stateno = 200 || stateno = 400 || stateno = 430) && animelemtime(4)>=0) || ((stateno = 230 || stateno = 210 || stateno = 205) && animelemtime(5)>=0) || ((stateno = 240 || stateno = 640) && animelemtime(9)>=0)


[State -1, Stand Punch]
type = ChangeState
value = 1100
triggerall = (var(55)<5 && (((command = "punch" && command = "kick") || (command = "specops")) && command = "holddown")) || var(52) = 1100
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = ((stateno = 200 || stateno = 400 || stateno = 430) && animelemtime(4)>=0) || ((stateno = 230 || stateno = 210 || stateno = 205) && animelemtime(5)>=0) || ((stateno = 240 || stateno = 640) && animelemtime(9)>=0)

[State -1, Stand Punch]
type = ChangeState
value = 1150
triggerall = (var(55)<5 && (((command = "punch" && command = "kick") || (command = "specops")))) || var(52) = 1150
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = ((stateno = 200 || stateno = 400 || stateno = 430) && animelemtime(4)>=0) || ((stateno = 230 || stateno = 210 || stateno = 205) && animelemtime(5)>=0) || ((stateno = 240 || stateno = 640) && animelemtime(9)>=0)

;---------------------------------------------------------------------------
[State -1, Stand Punch]
type = ChangeState
value = 210
triggerall = (var(55)<5 && (command = "punch" && command != "kick" && command != "holddown" && command = "holdfwd")) || var(52) = 210
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (var(55)<5 && (command = "tap")) || var(52) = 210
trigger2 = power >= 100
trigger2 = ((stateno = 200 || stateno = 400 || stateno = 430) && animelemtime(4)>=0) || ((stateno = 230 || stateno = 210 || stateno = 205) && animelemtime(5)>=0) || ((stateno = 240 || stateno = 640) && animelemtime(9)>=0)

[State -1, Stand Punch]
type = ChangeState
value = 205
triggerall = (var(55)<5 && (command = "punch" && command != "kick" && command != "holddown"  && command = "holdback")) || var(52) = 205
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (var(55)<5 && (command = "tap")) || var(52) = 205
trigger2 = power >= 100
trigger2 = ((stateno = 200 || stateno = 400 || stateno = 430) && animelemtime(4)>=0) || ((stateno = 230 || stateno = 210 || stateno = 205) && animelemtime(5)>=0) || ((stateno = 240 || stateno = 640) && animelemtime(9)>=0)

[State -1, Stand Punch]
type = ChangeState
value = 200
triggerall = (var(55)<5 && (command = "punch" && command != "kick" && command != "holddown")) || var(52) = 200
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (var(55)<5 && (command = "tap")) || var(52) = 200
trigger2 = power >= 100
trigger2 = ((stateno = 200 || stateno = 400 || stateno = 430) && animelemtime(4)>=0) || ((stateno = 230 || stateno = 210 || stateno = 205) && animelemtime(5)>=0) || ((stateno = 240 || stateno = 640) && animelemtime(9)>=0)

[State -1, Stand Punch]
type = ChangeState
value = 400
triggerall = (var(55)<5 && (command = "punch" && command != "kick" && command = "holddown")) || var(52) = 400
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (var(55)<5 && (command = "tap")) || var(52) = 400
trigger2 = power >= 100
trigger2 = ((stateno = 200 || stateno = 400 || stateno = 430) && animelemtime(4)>=0) || ((stateno = 230 || stateno = 210 || stateno = 205) && animelemtime(5)>=0) || ((stateno = 240 || stateno = 640) && animelemtime(9)>=0)

[State -1, Stand Punch]
type = ChangeState
value = 640
triggerall = (var(55)<5 && (command = "kick" && command != "punch" && command = "holdfwd")) || var(52) = 640
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (var(55)<5 && (command = "tak")) || var(52) = 640
trigger2 = power >= 100
trigger2 = ((stateno = 200 || stateno = 400 || stateno = 430) && animelemtime(4)>=0) || ((stateno = 230 || stateno = 210 || stateno = 205) && animelemtime(5)>=0) || ((stateno = 240 || stateno = 640) && animelemtime(9)>=0)

[State -1, Stand Punch]
type = ChangeState
value = 240
triggerall = (var(55)<5 && (command = "kick" && command != "punch" && command = "holdback")) || var(52) = 240
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (var(55)<5 && (command = "tak")) || var(52) = 240
trigger2 = power >= 100
trigger2 = ((stateno = 200 || stateno = 400 || stateno = 430) && animelemtime(4)>=0) || ((stateno = 230 || stateno = 210 || stateno = 205) && animelemtime(5)>=0) || ((stateno = 240 || stateno = 640) && animelemtime(9)>=0)

[State -1, Stand Punch]
type = ChangeState
value = 430
triggerall = (var(55)<5 && (command = "kick" && command != "punch" && command = "holddown")) || var(52) = 430
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (var(55)<5 && (command = "tak")) || var(52) = 430
trigger2 = power >= 100
trigger2 = ((stateno = 200 || stateno = 400 || stateno = 430) && animelemtime(4)>=0) || ((stateno = 230 || stateno = 210 || stateno = 205) && animelemtime(5)>=0) || ((stateno = 240 || stateno = 640) && animelemtime(9)>=0)

[State -1, Stand Punch]
type = ChangeState
value = 230
triggerall = (var(55)<5 && (command = "kick" && command != "punch")) || var(52) = 230
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (var(55)<5 && (command = "tak")) || var(52) = 230
trigger2 = power >= 100
trigger2 = ((stateno = 200 || stateno = 400 || stateno = 430) && animelemtime(4)>=0) || ((stateno = 230 || stateno = 210 || stateno = 205) && animelemtime(5)>=0) || ((stateno = 240 || stateno = 640) && animelemtime(9)>=0)

[State -1, HYPER COMBO FINISH]
type = ChangeState
value = 1000
trigger1 = (var(55)<5 && (command = "tak" || command = "tap")) || (var(52) = [200,640])
trigger1 = power < 100
trigger1 = prevstateno = [200,640]
trigger1 =  ((stateno = 200 || stateno = 400 || stateno = 430) && animelemtime(4)>=0) || ((stateno = 230 || stateno = 210 || stateno = 205) && animelemtime(5)>=0) || ((stateno = 240 || stateno = 640) && animelemtime(9)>=0)
trigger1 = movehit

[State -1, Air Attack]
type = ChangeState
value = 630
triggerall = (var(55)<5 && (command = "kick" || command = "punch" || command = "specops")) || var(52) = 630
trigger1 = statetype = A
trigger1 = ctrl

[State -1, lol]
type = ChangeState
value = 100
triggerall = var(52) = 100
trigger1 = statetype != A
trigger1 = ctrl

[State -1, lol]
type = ChangeState
value = 105
triggerall = var(52) = 105
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Test]
type = null;ChangeState
value = 181
triggerall = (var(55)<5 && (command = "start"))
trigger1 = statetype != A
trigger1 = ctrl


